.. mrrt.nufft documentation master file, created by sphinx-quickstart on Tue Apr 14 10:29:06 2015. You can adapt this file completely to your liking, but it should at least contain the root `toctree` directive.

Welcome to mrrt.nufft's documentation!
======================================

`mrrt.nufft` is a package for computing non-uniform fast Fourier transforms
(NUFFT) as used in MRI.  Multithreaded CPU implementations exist in this
package.  A Non-Cartesian MRI system operator including coil sensitivities and
field maps is available in mrrt.operators_private.  A GPU implementation is
available via mrrt.cuda.

For more information, please refer to the readme_ in the Github repository.

This documentation was generated using sphinx_.

.. _sphinx: http://sphinx-doc.org/
.. _readme: https://github.com/grlee77/mrrt.nufft/blob/master/README.rst
.. _COPYING: https://github.com/grlee77/mrrt.nufft/blob/master/COPYING

Contents:

.. toctree::
   :maxdepth: 2

   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

